@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def get(vmanage):
     """
     Get policy lists
@@ -13,8 +10,8 @@ def get(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/prefix"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def create(vmanage, policylist):
@@ -30,8 +27,8 @@ def create(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/prefix"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def preview(vmanage, policylist):
@@ -47,8 +44,8 @@ def preview(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix/preview"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/prefix/preview"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def previewById(vmanage, id):
@@ -64,8 +61,8 @@ def previewById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix/preview/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/prefix/preview/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getListsById(vmanage, id):
@@ -81,8 +78,8 @@ def getListsById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/prefix/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def edit(vmanage, policylist, id):
@@ -99,8 +96,8 @@ def edit(vmanage, policylist, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/prefix/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policylist)
     return response
 
 def delete(vmanage, id):
@@ -116,6 +113,6 @@ def delete(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/prefix/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/list/prefix/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
