@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def updateLeaseTime(vmanage, processId):
     """
     Update lease
@@ -14,8 +11,8 @@ def updateLeaseTime(vmanage, processId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/lock/{processId}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint)
+    endpoint = f"dataservice/template/lock/{processId}"
+    response = vmanage.apiCall("PUT", endpoint)
     return response
 
 def removeLock(vmanage, processId):
@@ -31,6 +28,6 @@ def removeLock(vmanage, processId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/lock/{processId}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/lock/{processId}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
