@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def editDeviceWithLicense(vmanage, license):
     """
     Update device subscription
@@ -14,8 +11,8 @@ def editDeviceWithLicense(vmanage, license):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/assignLicense"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, license)
+    endpoint = f"dataservice/msla/assignLicense"
+    response = vmanage.apiCall("PUT", endpoint, license)
     return response
 def createDeviceWithLicense(vmanage, license):
     """
@@ -30,8 +27,8 @@ def createDeviceWithLicense(vmanage, license):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/assignLicense"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, license)
+    endpoint = f"dataservice/msla/assignLicense"
+    response = vmanage.apiCall("POST", endpoint, license)
     return response
 def getMSLADevices(vmanage):
     """
@@ -45,8 +42,8 @@ def getMSLADevices(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/devices"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/devices"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDeviceDistributionOverview(vmanage):
     """
@@ -60,8 +57,8 @@ def getDeviceDistributionOverview(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/devices/assignmentdistribution"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/devices/assignmentdistribution"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLicenseandDeviceOverview(vmanage):
     """
@@ -75,8 +72,8 @@ def getLicenseandDeviceOverview(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/devices/licenseanddeviceoverviewtable"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/devices/licenseanddeviceoverviewtable"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLicenseDistributionOverview(vmanage):
     """
@@ -90,8 +87,8 @@ def getLicenseDistributionOverview(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/devices/licensedistribution"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/devices/licensedistribution"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSubscriptionOverview(vmanage):
     """
@@ -105,8 +102,8 @@ def getSubscriptionOverview(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/devices/subscriptiondistribution"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/devices/subscriptiondistribution"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSubscriptions(vmanage, payload):
     """
@@ -121,8 +118,8 @@ def getSubscriptions(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/licenses/subscription"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/msla/licenses/subscription"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def syncLicenses(vmanage, synclicense):
     """
@@ -137,8 +134,8 @@ def syncLicenses(vmanage, synclicense):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/licenses/sync"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, synclicense)
+    endpoint = f"dataservice/msla/licenses/sync"
+    response = vmanage.apiCall("POST", endpoint, synclicense)
     return response
 def getlicensedDeviceCount(vmanage):
     """
@@ -152,8 +149,8 @@ def getlicensedDeviceCount(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/monitoring/licensedDeviceCount"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/monitoring/licensedDeviceCount"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLicensedDistributionDetails(vmanage):
     """
@@ -167,8 +164,8 @@ def getLicensedDistributionDetails(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/monitoring/licensedDistributionDetails"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/monitoring/licensedDistributionDetails"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getpackagingDistributionDetails(vmanage):
     """
@@ -182,8 +179,8 @@ def getpackagingDistributionDetails(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/monitoring/packagingDistributionDetails"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/monitoring/packagingDistributionDetails"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSubscriptions(vmanage):
     """
@@ -197,8 +194,8 @@ def getSubscriptions(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/subscriptions"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/subscriptions"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getAllTemplate(vmanage):
     """
@@ -212,8 +209,8 @@ def getAllTemplate(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/template"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/msla/template"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSubscriptions(vmanage, payload):
     """
@@ -228,8 +225,8 @@ def getSubscriptions(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/template/licenses"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/msla/template/licenses"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
 def getSubscriptions(vmanage, payload):
     """
@@ -244,6 +241,6 @@ def getSubscriptions(vmanage, payload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/msla/va/License"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, payload)
+    endpoint = f"dataservice/msla/va/License"
+    response = vmanage.apiCall("POST", endpoint, payload)
     return response
